@@ -14,6 +14,19 @@ import os
 
 name = 'telegram_util'
 
+def hasSeq(text, sequences):
+    if not text:
+        return False
+    for seq in sequences:
+        index = 0
+        for char in seq:
+            index = text.find(char, index)
+            if index == -1:
+                break
+        if index != -1:
+            return True
+    return False
+
 def isprintable(s):
     try: 
     	s.encode('utf-8')
@@ -108,6 +121,16 @@ class AlbumResult(object):
 	def empty(self):
 		return (not self.imgs) and (not self.cap) and (not self.video) and (not self.cap_html_v2)
 
+	def toPlain(self):
+		new_album = AlbumResult()
+		new_album.imgs = self.imgs
+		new_album.video = self.video
+		if self.cap_html_v2:
+			new_album.cap_html_v2 = (self.cap_html_v2.strip() + '\n\n' + self.url).strip()
+		elif self.cap or self.imgs or self.video:
+			new_album.cap = (self.cap.strip() + '\n\n' + self.url).strip()
+		return new_album
+
 	def __str__(self):
 		return '\t'.join([k + ':' + str(v) for (k,v) in self.__dict__.items() if v])
 
